pub struct ScrollStateUpdate {
pub scrolled_node: ExternalScrollId,
pub offsets: FxHashMap<ExternalScrollId, LayoutVector2D>,
}Expand description
A data structure which contains information for the pipeline after a scroll happens in the
embedder-side WebView.
Fields
scrolled_node: ExternalScrollIdThe ExternalScrollId of the node that that was scrolled.
offsets: FxHashMap<ExternalScrollId, LayoutVector2D>A map containing the scroll offsets of the entire scroll tree. This is necessary, because scroll events can cause other nodes to scroll due to sticky positioning.